==> plugin-android-3.0.4-sources.jar: com/zoyi/channel/plugin/android/ChannelPluginSettings.java <==
package com.zoyi.channel.plugin.android;

import android.support.annotation.NonNull;

public class ChannelPluginSettings {
  private String pluginKey;
  private boolean debugMode;
  private boolean hideDefaultLauncher;
  private boolean enabledTrackDefaultEvent;
  private boolean hideDefaultInAppPush;

  public ChannelPluginSettings(@NonNull String pluginKey) {
    this.pluginKey = pluginKey;
    this.debugMode = false;
    this.hideDefaultLauncher = false;
    this.enabledTrackDefaultEvent = true;
    this.hideDefaultInAppPush = false;
  }

  public ChannelPluginSettings setDebugMode(boolean debug) {
    this.debugMode = debug;
    return this;
  }

  public ChannelPluginSettings setHideDefaultLauncher(boolean hideDefaultLauncher) {
    this.hideDefaultLauncher = hideDefaultLauncher;
    return this;
  }

  public ChannelPluginSettings setEnabledTrackDefaultEvent(boolean enabledTrackDefaultEvent) {
    this.enabledTrackDefaultEvent = enabledTrackDefaultEvent;
    return this;
  }

  public ChannelPluginSettings setHideDefaultInAppPush(boolean hideDefaultInAppPush) {
    this.hideDefaultInAppPush = hideDefaultInAppPush;
    return this;
  }

  public String getPluginKey() {
    return pluginKey;
  }

  public boolean isDebugMode() {
    return debugMode;
  }

  public boolean isHideDefaultLauncher() {
    return hideDefaultLauncher;
  }

  public boolean isEnabledTrackDefaultEvent() {
    return enabledTrackDefaultEvent;
  }

  public boolean isHideDefaultInAppPush() {
    return hideDefaultInAppPush;
  }
}

==> plugin-android-3.1.5-sources.jar: com/zoyi/channel/plugin/android/ChannelPluginSettings.java <==
package com.zoyi.channel.plugin.android;

import android.support.annotation.NonNull;

public class ChannelPluginSettings {
  private String pluginKey;
  private String userId;
  private boolean debugMode;
  private boolean hideDefaultLauncher;
  private boolean enabledTrackDefaultEvent;
  private boolean hideDefaultInAppPush;
  private CHLocale locale;

  public ChannelPluginSettings(@NonNull String pluginKey) {
    this.pluginKey = pluginKey;
    this.debugMode = false;
    this.hideDefaultLauncher = false;
    this.enabledTrackDefaultEvent = true;
    this.hideDefaultInAppPush = false;
  }

  public static ChannelPluginSettings create(@NonNull String pluginKey) {
    return new ChannelPluginSettings(pluginKey);
  }

  public ChannelPluginSettings setUserId(String userId) {
    this.userId = userId;
    return this;
  }

  public ChannelPluginSettings setDebugMode(boolean debug) {
    this.debugMode = debug;
    return this;
  }

  public ChannelPluginSettings setHideDefaultLauncher(boolean hideDefaultLauncher) {
    this.hideDefaultLauncher = hideDefaultLauncher;
    return this;
  }

  public ChannelPluginSettings setEnabledTrackDefaultEvent(boolean enabledTrackDefaultEvent) {
    this.enabledTrackDefaultEvent = enabledTrackDefaultEvent;
    return this;
  }

  public ChannelPluginSettings setHideDefaultInAppPush(boolean hideDefaultInAppPush) {
    this.hideDefaultInAppPush = hideDefaultInAppPush;
    return this;
  }

  public ChannelPluginSettings setLocale(CHLocale locale) {
    this.locale = locale;
    return this;
  }

  public String getPluginKey() {
    return pluginKey;
  }

  public String getUserId() {
    return userId;
  }

  public boolean isDebugMode() {
    return debugMode;
  }

  public boolean isHideDefaultLauncher() {
    return hideDefaultLauncher;
  }

  public boolean isEnabledTrackDefaultEvent() {
    return enabledTrackDefaultEvent;
  }

  public boolean isHideDefaultInAppPush() {
    return hideDefaultInAppPush;
  }

  public CHLocale getLocale() {
    return locale;
  }
}
